@@ -7,16 +7,12 @@ use utf8;
 
 use parent qw(Tickit::ContainerWidget);
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 =head1 NAME
 
 Tickit::Widget::Layout::Desktop - provides a holder for "desktop-like" widget behaviour
 
-=head1 VERSION
-
-version 0.010
-
 =head1 SYNOPSIS
 
  #!/usr/bin/env perl
@@ -142,7 +138,7 @@ sub overlay {
 
 	# Each child widget, from back to front
 	CHILD:
-	foreach my $child (reverse grep defined, map $win_map{refaddr($_)}, @{$self->window->{child_windows}}) {
+	foreach my $child (reverse grep defined, map $win_map{refaddr($_)}, $self->window->subwindows) {
 		next CHILD unless my $w = $child->window;
 		next CHILD unless $w->rect->intersects($target);
 
@@ -465,7 +461,7 @@ Arrange all the windows in a cascade (first at 1,1, second at 2,2, etc.).
 
 sub cascade {
 	my $self = shift;
-	my @windows = reverse @{$self->window->{child_windows}};
+	my @windows = reverse $self->window->subwindows;
 	my $x = 0;
 	my $y = 0;
 	my $lines = $self->window->lines - @windows;
@@ -537,7 +533,7 @@ Close all the windows.
 
 sub close_all {
 	my $self = shift;
-	$_->close for reverse @{$self->window->{child_windows}};
+	$_->close for reverse $self->window->subwindows;
 }
 
 sub close_panel {
@@ -546,8 +542,9 @@ sub close_panel {
 	my $addr = refaddr($panel);
 	List::UtilsBy::extract_by { refaddr($_) == $addr }@{ $self->{widgets} };
 	$panel->window->close;
-	$self->window->tickit->later(sub {
-		$self->window->expose($rect);
+	my $win = $self->window;
+	$win->tickit->later(sub {
+		$win->expose($rect);
 	})
 }
 
@@ -575,4 +572,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2016. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2017. Licensed under the same terms as Perl itself.
+
